---
name: Bug report
about: Create a bug report to help us improve
title: "[BUG]"
labels: bug
assignees: ''

---

* glob-linters version:
* Python version: (if using glob-linters in command line)
* Operating System: (if using glob-linters in command line)

### Description

Describe what you were trying to get done.
Tell us what happened, what went wrong, and what you expected to happen.

### What I Did

```
Paste the command(s) you ran and the output as well as any configuration you applied.
If there was a crash, please include the traceback here.
```
